@@ -1,7 +1,7 @@
 import itertools
 
 from enum import Enum
-from sentry_sdk._types import TYPE_CHECKING
+from typing import TYPE_CHECKING
 
 # up top to prevent circular import due to integration import
 DEFAULT_MAX_VALUE_LENGTH = 1024
@@ -53,7 +53,6 @@ if TYPE_CHECKING:
     Experiments = TypedDict(
         "Experiments",
         {
-            "attach_explain_plans": dict[str, Any],
             "max_spans": Optional[int],
             "record_sql_params": Optional[bool],
             "continuous_profiling_auto_start": Optional[bool],
@@ -567,4 +566,4 @@ DEFAULT_OPTIONS = _get_default_options()
 del _get_default_options
 
 
-VERSION = "2.13.0"
+VERSION = "2.15.0"
