@@ -1,9 +1,9 @@
 from abc import ABC, abstractmethod
 from threading import Lock
 
-from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.utils import logger
 
+from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
@@ -16,6 +16,9 @@ if TYPE_CHECKING:
     from typing import Type
 
 
+_DEFAULT_FAILED_REQUEST_STATUS_CODES = frozenset(range(500, 600))
+
+
 _installer_lock = Lock()
 
 # Set of all integration identifiers we have attempted to install
