@@ -1,3 +1,5 @@
+import functools
+
 import sentry_sdk
 from sentry_sdk.tracing import SOURCE_FOR_STYLE
 from sentry_sdk.utils import (
@@ -10,7 +12,8 @@ from sentry_sdk.utils import (
 from sentry_sdk.integrations import Integration, DidNotEnable
 from sentry_sdk.integrations.wsgi import SentryWsgiMiddleware
 from sentry_sdk.integrations._wsgi_common import RequestExtractor
-from sentry_sdk._types import TYPE_CHECKING
+
+from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from sentry_sdk.integrations.wsgi import _ScopedResponse
@@ -80,10 +83,12 @@ class BottleIntegration(Integration):
 
         old_handle = Bottle._handle
 
-        @ensure_integration_enabled(BottleIntegration, old_handle)
+        @functools.wraps(old_handle)
         def _patched_handle(self, environ):
             # type: (Bottle, Dict[str, Any]) -> Any
             integration = sentry_sdk.get_client().get_integration(BottleIntegration)
+            if integration is None:
+                return old_handle(self, environ)
 
             scope = sentry_sdk.get_isolation_scope()
             scope._name = "bottle"
