@@ -1,3 +1,4 @@
+import functools
 import hashlib
 from inspect import isawaitable
 
@@ -87,10 +88,13 @@ def _patch_schema_init():
     # type: () -> None
     old_schema_init = Schema.__init__
 
-    @ensure_integration_enabled(StrawberryIntegration, old_schema_init)
+    @functools.wraps(old_schema_init)
     def _sentry_patched_schema_init(self, *args, **kwargs):
         # type: (Schema, Any, Any) -> None
         integration = sentry_sdk.get_client().get_integration(StrawberryIntegration)
+        if integration is None:
+            return old_schema_init(self, *args, **kwargs)
+
         extensions = kwargs.get("extensions") or []
 
         if integration.async_execution is not None:
@@ -182,13 +186,13 @@ class SentryAsyncExtension(SchemaExtension):  # type: ignore
         if span:
             self.graphql_span = span.start_child(
                 op=op,
-                description=description,
+                name=description,
                 origin=StrawberryIntegration.origin,
             )
         else:
             self.graphql_span = sentry_sdk.start_span(
                 op=op,
-                description=description,
+                name=description,
                 origin=StrawberryIntegration.origin,
             )
 
@@ -211,7 +215,7 @@ class SentryAsyncExtension(SchemaExtension):  # type: ignore
         # type: () -> Generator[None, None, None]
         self.validation_span = self.graphql_span.start_child(
             op=OP.GRAPHQL_VALIDATE,
-            description="validation",
+            name="validation",
             origin=StrawberryIntegration.origin,
         )
 
@@ -223,7 +227,7 @@ class SentryAsyncExtension(SchemaExtension):  # type: ignore
         # type: () -> Generator[None, None, None]
         self.parsing_span = self.graphql_span.start_child(
             op=OP.GRAPHQL_PARSE,
-            description="parsing",
+            name="parsing",
             origin=StrawberryIntegration.origin,
         )
 
@@ -253,7 +257,7 @@ class SentryAsyncExtension(SchemaExtension):  # type: ignore
 
         with self.graphql_span.start_child(
             op=OP.GRAPHQL_RESOLVE,
-            description="resolving {}".format(field_path),
+            name="resolving {}".format(field_path),
             origin=StrawberryIntegration.origin,
         ) as span:
             span.set_data("graphql.field_name", info.field_name)
@@ -274,7 +278,7 @@ class SentrySyncExtension(SentryAsyncExtension):
 
         with self.graphql_span.start_child(
             op=OP.GRAPHQL_RESOLVE,
-            description="resolving {}".format(field_path),
+            name="resolving {}".format(field_path),
             origin=StrawberryIntegration.origin,
         ) as span:
             span.set_data("graphql.field_name", info.field_name)
